@@ -1,5 +1,5 @@
 #!python
-# Copyright (c) 2012, Sven Thiele <sthiele78@gmail.com>
+# Copyright (c) 2012-2013, Santiago Videla, Sven Thiele, CNRS, INRIA, EMBL
 #
 # This file is part of caspo.
 #
@@ -21,22 +21,19 @@ from optparse import OptionParser
 from __caspo__ import bioasp, utils, writer
 
 if __name__ == '__main__':
-    usage = "usage: %prog [options] pkn.sif midas.csv" 
+    usage = "Usage: %prog [options] pkn.sif midas.csv" 
     parser = OptionParser(usage)
     parser.add_option("-t", "--tolerance", dest="tolerance", type='float', default=0.,
-                      help="Suboptimal enumeration tolerance: 0 <= t <= 0.5 (Default to 0)", metavar="T")
+                      help="suboptimal enumeration tolerance: 0 <= t <= 0.5 (Default to 0)", metavar="T")
 
     parser.add_option("-p", "--discrete", dest="pvalue", type="int", default=2,
-                      help="Discretization range exponent: 10^P (Default to 2)", metavar="P")
-                      
-    parser.add_option("-q", "--alpha", dest="qvalue", type="int", default=5,
-                    help="Size penalty exponent 1/10^Q (Default to 5)", metavar="Q")
-                    
+                      help="discretization over the integer interval: [0,10^P] (Default to 2)", metavar="P")
+                                          
     parser.add_option("-g", "--gtts", dest="gtts", action='store_true', default=False,
-                  help="Compute Global Truth Tables (Default to False). This could take some time for many models.")
+                  help="compute Global Truth Tables (Default to False). This could take some time for many models.")
 
     parser.add_option("-o", "--outdir", dest="outdir", default='.',
-                    help="Output directory path (Default to current directory)", metavar="O")
+                    help="output directory path (Default to current directory)", metavar="O")
 
     (options, args) = parser.parse_args()
 
@@ -47,9 +44,6 @@ if __name__ == '__main__':
     if options.pvalue not in allowed:
         parser.error("incorrect value for discretization range: %s. Allowed values: %s" % (options.pvalue, allowed))
 
-    if options.qvalue - 2*options.pvalue < 0:
-        parser.error("incorrect value for discretization range %s or size penalty %s. They must satisfy q - 2p >= 0" % (options.pvalue, options.qvalue))
-    
     allowed_tol = 0.5
     if options.tolerance > allowed_tol or options.tolerance < 0:
         parser.error("incorrect value for tolerance: %s. Allowed values are: 0 <= t <= %s" % (options.tolerance, allowed_tol))
@@ -57,7 +51,7 @@ if __name__ == '__main__':
     pkn = args[0]
     midas = args[1]
     
-    models, score, optsize, data, instance = bioasp.optimize(pkn,midas,options.tolerance,options.pvalue,options.qvalue)
+    models, score, optsize, data, instance = bioasp.optimize(pkn,midas,options.tolerance,options.pvalue)
     
     print "\nProcessing %s boolean models..." % len(models)
     hyperedges = bioasp.get_hyperedges(instance)
@@ -65,7 +59,7 @@ if __name__ == '__main__':
     
     if not os.path.exists(options.outdir):
         os.mkdir(options.outdir)
-    
+
     writer.write_models(matrix, hyperedges, options.outdir)
     writer.write_frequencies(matrix, hyperedges, options.outdir)
     
